
import Foundation

struct RawConversation : Codable {
    var date: String
    var displayName: String?
    var guid: String
    public var lastMessagePreview: String
    var participantDisplayNames: [String]
    var unreadCount: Int
    
    var conversation: Conversation {
        let convo = Conversation(guid: guid,
                                 date: .from(kordophoneDate: date),
                                 participants: participantDisplayNames,
                                 displayName: displayName,
                                 lastMessagePreview: lastMessagePreview,
                                 unreadCount: unreadCount)
                
        return convo
    }
}

public struct Conversation {
    var guid: String = UUID().uuidString
    public var date: Date = .now
    public var participants: [String] = .init()
    public var displayName: String?
    public var lastMessagePreview: String = ""
    public var unreadCount: Int = 0
    
    public var effectiveDisplayName: String {
        displayName ?? participants.joined(separator: ",")
    }
}

extension Conversation : Hashable, Identifiable {
    public var id: String { guid }
}

extension Conversation {
    public static var samples: [Conversation] {
        [
            Conversation(date: .init(timeIntervalSinceNow: -3600), lastMessagePreview: "3600s ago"),
            Conversation(date: .now, lastMessagePreview: "unread now", unreadCount: 1)
        ]
    }
}
