
import Foundation

struct RawMessage : Codable {
    var date: String
    var guid: String
    var sender: String?
    var text: String
    var fileTransferGUIDs: [String]?
    
    var message: Message {
        let message = Message(guid: guid,
                              date: .from(kordophoneDate: date),
                              sender: sender,
                              text: text,
                              attachments: (fileTransferGUIDs ?? [String]()).map {
            Attachment(guid: $0)
        })
        
        return message
    }
}

public struct Message {
    var guid: String = UUID().uuidString
    public var date: Date = .now
    public var sender: String?
    public var text: String
    public var attachments: [Attachment] = .init()
}

extension Message {
    public var sentByMe: Bool {
        sender == nil
    }
}

extension Message : Codable, Hashable, Identifiable {
    public var id: String { guid }
}
